[Asterisk-cvs] asterisk/include/asterisk srv.h,1.2,1.3

kpfleming kpfleming
Thu Aug 25 19:21:41 CDT 2005


Update of /usr/cvsroot/asterisk/include/asterisk
In directory mongoose.digium.com:/tmp/cvs-serv1780/include/asterisk

Modified Files:
	srv.h 
Log Message:
doc updates and copyright header cleanup (issue #5026)


Index: srv.h
===================================================================
RCS file: /usr/cvsroot/asterisk/include/asterisk/srv.h,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -d -r1.2 -r1.3
--- srv.h	8 Sep 2003 16:48:07 -0000	1.2
+++ srv.h	25 Aug 2005 23:23:26 -0000	1.3
@@ -1,14 +1,16 @@
 /*
  * Asterisk -- A telephony toolkit for Linux.
  *
- * ENUM support
+ * DNS SRV record support
  * 
- * Copyright (C) 1999, Mark Spencer
+ * Copyright (C) 1999-2005, Digium, Inc.
  *
- * Mark Spencer <markster at linux-support.net>
+ * Mark Spencer <markster at digium.com>
  *
  * This program is free software, distributed under the terms of
  * the GNU General Public License
+ * 
+ * $Revision$
  */
 
 #ifndef _ASTERISK_SRV_H
@@ -16,7 +18,23 @@
 
 struct ast_channel;
 
-/* Lookup entry in SRV records Returns 1 if found, 0 if not found, -1 on hangup */
+/*!
+  \file srv.h
+  \brief Support for DNS SRV records, used in to locate SIP services.
+	Note: The Asterisk DNS SRV record support is broken, it only
+	supports the first DNS SRV record and will give no load 
+	balancing or failover support.
+*/
+
+/*! Lookup entry in SRV records Returns 1 if found, 0 if not found, -1 on hangup 
+	Only do SRV record lookup if you get a domain without a port. If you get a port #, it's a DNS host name.
+*/
+/*!	\param	chan Ast channel
+	\param	host host name (return value)
+	\param	hostlen Length of string "host"
+	\param	port Port number (return value)
+	\param service Service tag for SRV lookup (like "_sip._udp" or "_stun._udp"
+*/
 extern int ast_get_srv(struct ast_channel *chan, char *host, int hostlen, int *port, const char *service);
 
 #endif




More information about the svn-commits mailing list